Struct openssl::envelope::Open [−][src]
pub struct Open { /* fields omitted */ }Expand description
Represents an EVP_Open context.
Implementations
Creates a new Open.
Feeds data from input through the cipher, writing decrypted bytes into output.
The number of bytes written to output is returned. Note that this may
not be equal to the length of input.
Panics
Panics if output.len() < input.len() + block_size where
block_size is the block size of the cipher (see Cipher::block_size),
or if output.len() > c_int::max_value().
Finishes the decryption process, writing any remaining data to output.
The number of bytes written to output is returned.
update should not be called after this method.
Panics
Panics if output is less than the cipher’s block size.